# SatNOGS Config

SatNOGS client system configuration utility.


## Installation

To install the latest development version in editable mode run `pip install -e .` in the current directory.


## License

[![license](https://img.shields.io/badge/license-GPL%203.0-6672D8.svg)](LICENSE)
[![Libre Space Foundation](https://img.shields.io/badge/%C2%A9%202020-Libre%20Space%20Foundation-6672D8.svg)](https://librespacefoundation.org/)
